==> mingw-w64-rio-0.1.17-1.src.tar.zst: rio-0.1.17/docs/docs/default-key-bindings.md <==
---
layout: docs
class: docs
title: 'Default key bindings'
language: 'en'
---

### MacOS

| Action                 | Key                                                            |
| ---------------------- | -------------------------------------------------------------- |
| Open configuration     | `Command + Comma (,)`                                          |
| Toggle VI Mode         | `Alt + Shift + Space`                                          |
| Copy                   | `Command + C`                                                  |
| Paste                  | `Command + V`                                                  |
| Create new window      | `Command + N`                                                  |
| Create new tab         | `Command + T`                                                  |
| Move to next tab       | `Control + Tab` or `Command + Shift + RightBracket (])`        |
| Move to previous tab   | `Control + Shift + Tab` or `Command + Shift + LeftBracket ([)` |
| Increase font size     | `Command + Plus (+)`                                           |
| Decrease font size     | `Command + Minus (-)`                                          |
| Reset font size        | `Command + 0`                                                  |
| Minimize window        | `Command + M`                                                  |
| Quit                   | `Command + Q`                                                  |
| Close tab              | `Command + W`                                                  |
| Select the first tab   | `Command + 1`                                                  |
| Select the second tab  | `Command + 2`                                                  |
| Select the third tab   | `Command + 3`                                                  |
| Select the fourth tab  | `Command + 4`                                                  |
| Select the fifth tab   | `Command + 5`                                                  |
| Select the sixth tab   | `Command + 6`                                                  |
| Select the seventh tab | `Command + 7`                                                  |
| Select the eighth tab  | `Command + 8`                                                  |
| Select the last tab    | `Command + 9`          |
| Search forward         | `Command + f`          |
| Search backward        | `Command + b`          |

### Windows

| Action               | Key                                                         |
| -------------------- | ----------------------------------------------------------- |
| Open configuration   | `Control + Shift + Comma (,)`                               |
| Toggle VI Mode       | `Control + Shift + Space`                                   |
| Copy                 | `Control + Shift + C`                                       |
| Paste                | `Control + Shift + V`                                       |
| Create new window    | `Control + Shift + N`                                       |
| Create new tab       | `Control + Shift + T`                                       |
| Move to next tab     | `Control + Tab` or `Control + Shift + RightBracket (])`     |
| Move to previous tab | `Control + Shift + Tab` `Control + Shift + LeftBracket ([)` |
| Increase font size   | `Control + Plus (+)`                                        |
| Decrease font size   | `Control + Minus (-)`                                       |
| Reset font size      | `Control + 0`                                               |
| Close tab or quit    | `Control + Shift + W`                                       |
| Select the first tab   | `Control + Shift + 1`                                                  |
| Select the second tab  | `Control + Shift + 2`                                                  |
| Select the third tab   | `Control + Shift + 3`                                                  |
| Select the fourth tab  | `Control + Shift + 4`                                                  |
| Select the fifth tab   | `Control + Shift + 5`                                                  |
| Select the sixth tab   | `Control + Shift + 6`                                                  |
| Select the seventh tab | `Control + Shift + 7`                                                  |
| Select the eighth tab  | `Control + Shift + 8`                                                  |
| Select the last tab    | `Control + Shift + 9`   |
| Search forward         | `Control + Shift + f`  |
| Search backward        | `Control + Shift + b`  |

### Linux and BSD

| Action               | Key                                                            |
| -------------------- | -------------------------------------------------------------- |
| Open configuration   | `Control + Shift + Comma (,)`                                  |
| Toggle VI Mode       | `Alt + Shift + Space`                                          |
| Copy                 | `Control + Shift + C`                                          |
| Paste                | `Control + Shift + V`                                          |
| Create new window    | `Control + Shift + N`                                          |
| Create new tab       | `Control + Shift + T`                                          |
| Move to next tab     | `Control + Tab` or `Control + Shift + RightBracket (])`        |
| Move to previous tab | `Control + Shift + Tab` or `Control + Shift + LeftBracket ([)` |
| Increase font size   | `Control + Plus (+)`                                           |
| Decrease font size   | `Control + Minus (-)`                                          |
| Reset font size      | `Control + 0`                                                  |
| Close tab or quit    | `Control + Shift + W`                                          |
| Select the first tab   | `Control + Shift + 1`                                                  |
| Select the second tab  | `Control + Shift + 2`                                                  |
| Select the third tab   | `Control + Shift + 3`                                                  |
| Select the fourth tab  | `Control + Shift + 4`                                                  |
| Select the fifth tab   | `Control + Shift + 5`                                                  |
| Select the sixth tab   | `Control + Shift + 6`                                                  |
| Select the seventh tab | `Control + Shift + 7`                                                  |
| Select the eighth tab  | `Control + Shift + 8`                                                  |
| Select the last tab    | `Control + Shift + 9`          |
| Search forward          | `Control + Shift + f`  |
| Search backward         | `Control + Shift + b`  |

### Search

| Action                  | Key                                    |
| ----------------------- | -------------------------------------- |
| Quit search             | `Escape` (while search is open)        |
| Quit search             | `Control + c` (while search is open)   |
| Focus next              | `Enter` (while search is open)         |
| Focus previous          | `Shift + Enter` (while search is open) |
| Clear search word       | `Control + w` (while search is open)   |
| Search history previous | `Control + p` (while search is open)   |
| Search history previous | `ArrowUp` (while search is open)       |
| Search history next     | `Control + n` (while search is open)   |
| Search history next     | `ArrowDown` (while search is open)     |

==> mingw-w64-rio-0.2.2-1.src.tar.zst: rio-0.2.2/docs/docs/default-key-bindings.md <==
---
layout: docs
class: docs
title: 'Default key bindings'
language: 'en'
---

### MacOS

| Action                 | Key                                                            |
| ---------------------- | -------------------------------------------------------------- |
| Open configuration     | `Command + Comma (,)`                                          |
| Toggle VI Mode         | `Alt + Shift + Space`                                          |
| Copy                   | `Command + C`                                                  |
| Paste                  | `Command + V`                                                  |
| Create new window      | `Command + N`                                                  |
| Create new tab         | `Command + T`                                                  |
| Move to next tab       | `Control + Tab` or `Command + Shift + RightBracket (])`        |
| Move to previous tab   | `Control + Shift + Tab` or `Command + Shift + LeftBracket ([)` |
| Increase font size     | `Command + Plus (+)`                                           |
| Decrease font size     | `Command + Minus (-)`                                          |
| Reset font size        | `Command + 0`                                                  |
| Minimize window        | `Command + M`                                                  |
| Quit                   | `Command + Q`                                                  |
| Close tab              | `Command + W`                                                  |
| Select the first tab   | `Command + 1`                                                  |
| Select the second tab  | `Command + 2`                                                  |
| Select the third tab   | `Command + 3`                                                  |
| Select the fourth tab  | `Command + 4`                                                  |
| Select the fifth tab   | `Command + 5`                                                  |
| Select the sixth tab   | `Command + 6`                                                  |
| Select the seventh tab | `Command + 7`                                                  |
| Select the eighth tab  | `Command + 8`                                                  |
| Select the last tab    | `Command + 9`          |
| Search forward         | `Command + f`          |
| Search backward        | `Command + b`          |
| Split right    		 | `Command + d`          |
| Split down    		 | `Command + Shift + d`  |
| Select next split      | `Command + ]`          |
| Select prev split      | `Command + [`          |

### Windows

| Action               | Key                                                         |
| -------------------- | ----------------------------------------------------------- |
| Open configuration   | `Control + Shift + Comma (,)`                               |
| Toggle VI Mode       | `Control + Shift + Space`                                   |
| Copy                 | `Control + Shift + C`                                       |
| Paste                | `Control + Shift + V`                                       |
| Create new window    | `Control + Shift + N`                                       |
| Create new tab       | `Control + Shift + T`                                       |
| Move to next tab     | `Control + Tab` or `Control + Shift + RightBracket (])`     |
| Move to previous tab | `Control + Shift + Tab` `Control + Shift + LeftBracket ([)` |
| Increase font size   | `Control + Plus (+)`                                        |
| Decrease font size   | `Control + Minus (-)`                                       |
| Reset font size      | `Control + 0`                                               |
| Close tab or quit    | `Control + Shift + W`                                       |
| Select the first tab   | `Control + Shift + 1`                                                  |
| Select the second tab  | `Control + Shift + 2`                                                  |
| Select the third tab   | `Control + Shift + 3`                                                  |
| Select the fourth tab  | `Control + Shift + 4`                                                  |
| Select the fifth tab   | `Control + Shift + 5`                                                  |
| Select the sixth tab   | `Control + Shift + 6`                                                  |
| Select the seventh tab | `Control + Shift + 7`                                                  |
| Select the eighth tab  | `Control + Shift + 8`                                                  |
| Select the last tab    | `Control + Shift + 9`   |
| Search forward         | `Control + Shift + f`  |
| Search backward        | `Control + Shift + b`  |
| Split right    		 | `Control + Shift + r`  |
| Split down    		 | `Control + Shift + d`  |
| Select next split      | `Control + Shift + ]`  |
| Select prev split      | `Control + Shift + [`  |

### Linux and BSD

| Action               | Key                                                            |
| -------------------- | -------------------------------------------------------------- |
| Open configuration   | `Control + Shift + Comma (,)`                                  |
| Toggle VI Mode       | `Alt + Shift + Space`                                          |
| Copy                 | `Control + Shift + C`                                          |
| Paste                | `Control + Shift + V`                                          |
| Create new window    | `Control + Shift + N`                                          |
| Create new tab       | `Control + Shift + T`                                          |
| Move to next tab     | `Control + Tab` or `Control + Shift + RightBracket (])`        |
| Move to previous tab | `Control + Shift + Tab` or `Control + Shift + LeftBracket ([)` |
| Increase font size   | `Control + Plus (+)`                                           |
| Decrease font size   | `Control + Minus (-)`                                          |
| Reset font size      | `Control + 0`                                                  |
| Close tab or quit    | `Control + Shift + W`                                          |
| Select the first tab   | `Control + Shift + 1`                                                  |
| Select the second tab  | `Control + Shift + 2`                                                  |
| Select the third tab   | `Control + Shift + 3`                                                  |
| Select the fourth tab  | `Control + Shift + 4`                                                  |
| Select the fifth tab   | `Control + Shift + 5`                                                  |
| Select the sixth tab   | `Control + Shift + 6`                                                  |
| Select the seventh tab | `Control + Shift + 7`                                                  |
| Select the eighth tab  | `Control + Shift + 8`                                                  |
| Select the last tab    | `Control + Shift + 9`          |
| Search forward         | `Control + Shift + f`  |
| Search backward        | `Control + Shift + b`  |
| Split right    		 | `Control + Shift + r`  |
| Split down    		 | `Control + Shift + d`  |
| Select next split      | `Control + Shift + ]`  |
| Select prev split      | `Control + Shift + [`  |

### Search

| Action                  | Key                                    |
| ----------------------- | -------------------------------------- |
| Quit search             | `Escape` (while search is open)        |
| Quit search             | `Control + c` (while search is open)   |
| Focus next              | `Enter` (while search is open)         |
| Focus previous          | `Shift + Enter` (while search is open) |
| Clear search word       | `Control + w` (while search is open)   |
| Search history previous | `Control + p` (while search is open)   |
| Search history previous | `ArrowUp` (while search is open)       |
| Search history next     | `Control + n` (while search is open)   |
| Search history next     | `ArrowDown` (while search is open)     |
